Transpile context for Lua code generation.
This module provides context management for the transpilation process.
Structs
- Transpile
Context - Transpile context for sharing state during transpilation.
Transpile context for Lua code generation.
This module provides context management for the transpilation process.