LoaderError

Enum LoaderError 

pub enum LoaderError {
Show 15 variants Io(PathBuf, Error), Config(PathBuf, Error), ConfigNotFound(PathBuf), Parse { file: PathBuf, message: String, source: Option<ParseError>, }, Transpile(TranspileError), Runtime(Error), DirectoryNotFound(PathBuf), GlobPattern(PatternError), GlobTraversal(GlobError), CacheDirectoryError { path: PathBuf, source: Error, }, MetadataError { path: PathBuf, source: Error, }, CacheWriteError { path: PathBuf, source: Error, }, InvalidFileName(PathBuf), SceneDicGenerationError { reason: String, source: Option<Error>, }, PartialTranspileError { succeeded: usize, failed: usize, failures: Vec<TranspileFailure>, },
}
Loader error type for the startup sequence.

This error type covers all phases of the startup sequence:

  • Configuration loading and parsing
  • File system operations
  • Pasta file parsing
  • Transpilation
  • Lua runtime initialization

Variants



Io(PathBuf, Error)

File IO error.



Config(PathBuf, Error)

Configuration file parsing error.



ConfigNotFound(PathBuf)

Configuration file not found error.



Parse

Pasta file parsing error.

Fields

file: PathBuf
message: String


Transpile(TranspileError)

Transpilation error.



Runtime(Error)

Lua runtime initialization error.



DirectoryNotFound(PathBuf)

Directory not found error.



GlobPattern(PatternError)

Glob pattern error.



GlobTraversal(GlobError)

Glob traversal error.



CacheDirectoryError

Cache directory operation error.

Fields

path: PathBuf
source: Error


MetadataError

File metadata retrieval error.

Fields

path: PathBuf
source: Error


CacheWriteError

Cache file write error.

Fields

path: PathBuf
source: Error


InvalidFileName(PathBuf)

Invalid file name error (e.g., init.lua, init.pasta).



SceneDicGenerationError

scene_dic.lua generation error.

Fields

reason: String
source: Option<Error>


PartialTranspileError

Partial transpilation failure.

Fields

succeeded: usize
failed: usize

Implementations

Source

impl LoaderError

pub fn io(path: impl Into<PathBuf>, err: Error) -> Self

Create an IO error with file path.

pub fn config(path: impl Into<PathBuf>, err: Error) -> Self

Create a config error with file path.

pub fn config_not_found(path: impl Into<PathBuf>) -> Self

Create a config not found error with file path.

pub fn parse(path: impl Into<PathBuf>, message: impl Into<String>) -> Self

Create a parse error with file path and message.

pub fn parse_with_source( path: impl Into<PathBuf>, message: impl Into<String>, source: ParseError, ) -> Self

Create a parse error with source error.

pub fn directory_not_found(path: impl Into<PathBuf>) -> Self

Create a directory not found error.

pub fn invalid_file_name(path: impl Into<PathBuf>) -> Self

Create an invalid file name error.

pub fn cache_directory(path: impl Into<PathBuf>, err: Error) -> Self

Create a cache directory error.

pub fn metadata(path: impl Into<PathBuf>, err: Error) -> Self

Create a metadata error.

pub fn cache_write(path: impl Into<PathBuf>, err: Error) -> Self

Create a cache write error.

pub fn scene_dic_generation( reason: impl Into<String>, err: Option<Error>, ) -> Self

Create a scene_dic generation error.

pub fn partial_transpile( succeeded: usize, failed: usize, failures: Vec<TranspileFailure>, ) -> Self

Create a partial transpile error.