pub struct LoaderContext {
pub base_dir: PathBuf,
pub lua_search_paths: Vec<String>,
pub custom_fields: Table,
}Expand description
Context for runtime initialization from PastaLoader.
Contains all information needed to initialize PastaLuaRuntime from the loader context, including paths and custom configuration.
Fields
base_dir: PathBufBase directory (absolute path)
lua_search_paths: Vec<String>Lua module search paths (relative to base_dir)
custom_fields: TableCustom configuration fields from pasta.toml (everything except [loader] section)
Implementations
Sourceimpl LoaderContext
impl LoaderContext
Sourcepub fn new(
base_dir: impl Into<PathBuf>,
lua_search_paths: Vec<String>,
custom_fields: Table,
) -> Self
pub fn new( base_dir: impl Into<PathBuf>, lua_search_paths: Vec<String>, custom_fields: Table, ) -> Self
Create a new LoaderContext.
Sourcepub fn from_config(base_dir: &Path, config: &PastaConfig) -> Self
pub fn from_config(base_dir: &Path, config: &PastaConfig) -> Self
Create LoaderContext from PastaConfig.
Converts base_dir to absolute path and extracts relevant settings.
Sourcepub fn absolute_search_paths(&self) -> Vec<PathBuf>
pub fn absolute_search_paths(&self) -> Vec<PathBuf>
Generate absolute Lua module search paths.
Converts relative search paths to absolute paths based on base_dir.
Sourcepub fn generate_package_path(&self) -> String
pub fn generate_package_path(&self) -> String
Generate package.path string for Lua.
Creates a semicolon-separated path string in Lua format:
/path/to/dir/?.lua;/path/to/dir/?/init.lua;/next/path/?.lua;...
Each search path generates two patterns:
?.luafor direct module files?/init.luafor directory modules (likepasta/init.lua)
Sourcepub fn generate_package_path_bytes(&self) -> Result<Vec<u8>>
pub fn generate_package_path_bytes(&self) -> Result<Vec<u8>>
Generate package.path bytes for Lua.
Creates a semicolon-separated path string and converts it to system-native encoding bytes (ANSI on Windows, UTF-8 on Unix).
This is the preferred method for setting package.path in Lua
because Lua’s file I/O functions (fopen) use ANSI encoding on Windows.
Returns
Ok(Vec<u8>)- Encoded path bytes ready for LuaErr(std::io::Error)- If encoding conversion fails
Example
let bytes = loader_context.generate_package_path_bytes()?;
let lua_string = lua.create_string(&bytes)?;
package.set("path", lua_string)?;Trait Implementations
Sourceimpl Clone for LoaderContext
impl Clone for LoaderContext
Sourcefn clone(&self) -> LoaderContext
fn clone(&self) -> LoaderContext
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
source. Read moreAuto Trait Implementations
impl Freeze for LoaderContext
impl RefUnwindSafe for LoaderContext
impl Send for LoaderContext
impl Sync for LoaderContext
impl Unpin for LoaderContext
impl UnsafeUnpin for LoaderContext
impl UnwindSafe for LoaderContext