Module normalize

Module normalize 

Output normalization for Pasta Lua transpiler.

This module provides output buffer normalization to remove trailing blank lines and ensure consistent EOF markers.

Functions

normalize_output
Normalize output buffer by removing trailing blank lines and blank lines before end.