pub enum LoaderError {
Show 15 variants
Io(PathBuf, Error),
Config(PathBuf, Error),
ConfigNotFound(PathBuf),
Parse {
file: PathBuf,
message: String,
source: Option<ParseError>,
},
Transpile(TranspileError),
Runtime(Error),
DirectoryNotFound(PathBuf),
GlobPattern(PatternError),
GlobTraversal(GlobError),
CacheDirectoryError {
path: PathBuf,
source: Error,
},
MetadataError {
path: PathBuf,
source: Error,
},
CacheWriteError {
path: PathBuf,
source: Error,
},
InvalidFileName(PathBuf),
SceneDicGenerationError {
reason: String,
source: Option<Error>,
},
PartialTranspileError {
succeeded: usize,
failed: usize,
failures: Vec<TranspileFailure>,
},
}Expand description
Loader error type for the startup sequence.
This error type covers all phases of the startup sequence:
- Configuration loading and parsing
- File system operations
- Pasta file parsing
- Transpilation
- Lua runtime initialization
Variants
Io(PathBuf, Error)
File IO error.
Config(PathBuf, Error)
Configuration file parsing error.
ConfigNotFound(PathBuf)
Configuration file not found error.
Parse
Pasta file parsing error.
Transpile(TranspileError)
Transpilation error.
Runtime(Error)
Lua runtime initialization error.
DirectoryNotFound(PathBuf)
Directory not found error.
GlobPattern(PatternError)
Glob pattern error.
GlobTraversal(GlobError)
Glob traversal error.
CacheDirectoryError
Cache directory operation error.
MetadataError
File metadata retrieval error.
CacheWriteError
Cache file write error.
InvalidFileName(PathBuf)
Invalid file name error (e.g., init.lua, init.pasta).
SceneDicGenerationError
scene_dic.lua generation error.
PartialTranspileError
Partial transpilation failure.
Implementations
Sourceimpl LoaderError
impl LoaderError
Sourcepub fn config(path: impl Into<PathBuf>, err: Error) -> Self
pub fn config(path: impl Into<PathBuf>, err: Error) -> Self
Create a config error with file path.
Sourcepub fn config_not_found(path: impl Into<PathBuf>) -> Self
pub fn config_not_found(path: impl Into<PathBuf>) -> Self
Create a config not found error with file path.
Sourcepub fn parse(path: impl Into<PathBuf>, message: impl Into<String>) -> Self
pub fn parse(path: impl Into<PathBuf>, message: impl Into<String>) -> Self
Create a parse error with file path and message.
Sourcepub fn parse_with_source(
path: impl Into<PathBuf>,
message: impl Into<String>,
source: ParseError,
) -> Self
pub fn parse_with_source( path: impl Into<PathBuf>, message: impl Into<String>, source: ParseError, ) -> Self
Create a parse error with source error.
Sourcepub fn directory_not_found(path: impl Into<PathBuf>) -> Self
pub fn directory_not_found(path: impl Into<PathBuf>) -> Self
Create a directory not found error.
Sourcepub fn invalid_file_name(path: impl Into<PathBuf>) -> Self
pub fn invalid_file_name(path: impl Into<PathBuf>) -> Self
Create an invalid file name error.
Sourcepub fn cache_directory(path: impl Into<PathBuf>, err: Error) -> Self
pub fn cache_directory(path: impl Into<PathBuf>, err: Error) -> Self
Create a cache directory error.
Sourcepub fn cache_write(path: impl Into<PathBuf>, err: Error) -> Self
pub fn cache_write(path: impl Into<PathBuf>, err: Error) -> Self
Create a cache write error.
Sourcepub fn scene_dic_generation(
reason: impl Into<String>,
err: Option<Error>,
) -> Self
pub fn scene_dic_generation( reason: impl Into<String>, err: Option<Error>, ) -> Self
Create a scene_dic generation error.
Sourcepub fn partial_transpile(
succeeded: usize,
failed: usize,
failures: Vec<TranspileFailure>,
) -> Self
pub fn partial_transpile( succeeded: usize, failed: usize, failures: Vec<TranspileFailure>, ) -> Self
Create a partial transpile error.